@@ -17,11 +17,11 @@
 
 # Author: Cyril Jaquier
 # 
-# $Revision: 692 $
+# $Revision: 729 $
 
 __author__ = "Cyril Jaquier"
-__version__ = "$Revision: 692 $"
-__date__ = "$Date: 2008-05-18 21:53:18 +0200 (Sun, 18 May 2008) $"
+__version__ = "$Revision: 729 $"
+__date__ = "$Date: 2009-02-08 20:50:44 +0100 (Sun, 08 Feb 2009) $"
 __copyright__ = "Copyright (c) 2004 Cyril Jaquier"
 __license__ = "GPL"
 
@@ -132,7 +132,7 @@ class DateStrptime(DateTemplate):
 				conv = self.convertLocale(dateMatch.group())
 				try:
 					date = list(time.strptime(conv, self.getPattern()))
-				except ValueError:
+				except ValueError, e:
 					# Try to add the current year to the pattern. Should fix
 					# the "Feb 29" issue.
 					conv += " %s" % MyTime.gmtime()[0]
@@ -146,6 +146,11 @@ class DateStrptime(DateTemplate):
 				# that the log is not from this year but from the year before
 				if time.mktime(date) > MyTime.time():
 					date[0] -= 1
+				elif date[1] == 1 and date[2] == 1:
+					# If it is Jan 1st, it is either really Jan 1st or there
+					# is neither month nor day in the log.
+					date[1] = MyTime.gmtime()[1]
+					date[2] = MyTime.gmtime()[2]
 		return date
 
 
@@ -182,6 +187,5 @@ class DateISO8601(DateTemplate):
 		if dateMatch:
 			# Parses the date.
 			value = dateMatch.group()
-			print value
-			date = list(iso8601.parse_date(value).utctimetuple())
+			date = list(iso8601.parse_date(value).timetuple())
 		return date
